### Updates

The “Updates” section controls how Glyphs is updated.
Check for a new version of Glyphs by clicking on the “Check Now” button.
If one is available, Glyphs will offer to download the latest version and show a list of the new additions and changes.

“Automatically check for updates” will look periodically for new updates.
We recommend leaving this option selected.

Choose “Show cutting edge versions” to download beta versions of Glyphs.
Beta versions are released frequently, providing bug fixes and early feature releases.
Because of their frequency, beta versions are not as thoroughly tested as release versions.
Therefore, we recommend working with copies of font files when trying a Glyphs beta.
Revert to the latest stable version of Glyphs by re-downloading it from https://glyphsapp.com/buy.
Downloading a new version or reverting to an old version of Glyphs will _not_ reset the settings.